import Cookies from 'js-cookie'

import { ServerEndpointType } from '../context/models'
import { REFRESH_ACCESS_TOKEN_EXPIRE_BUFFER_MS, ACCESS_TOKEN_EXPIRY_COOKIE } from '../constants'

export const generateServerUrl = ({
  serverEndpoint,
  queryParams,
  serverUrl,
}: {
  serverEndpoint: ServerEndpointType
  queryParams?: Record<string, string>
  serverUrl: string
}) => {
  const query = new URLSearchParams(queryParams)
  const queryString = query.toString().length > 0 ? `?${query}` : ''
  const path = `/web${serverEndpoint}`

  return `${serverUrl}${path}${queryString}`
}

export const getRefreshAccessTokenInterval = () => {
  return Number(Cookies.get(ACCESS_TOKEN_EXPIRY_COOKIE)) - Date.now() - REFRESH_ACCESS_TOKEN_EXPIRE_BUFFER_MS
}

export const isAccessTokenValid = () => {
  const accessTokenExpiryCookie = Cookies.get(ACCESS_TOKEN_EXPIRY_COOKIE)

  if (Number(accessTokenExpiryCookie) >= Date.now()) return true
  else return false
}

export const refreshAccessTokenWithRedirect = ({ serverUrl, clientID }: { serverUrl: string; clientID: string }) => {
  const url = generateServerUrl({
    serverEndpoint: ServerEndpointType.tokenRefreshWithRedirect,
    serverUrl,
    queryParams: {
      client_id: clientID,
      redirect_uri: window.location.href,
    },
  })

  window.location.href = url
}

export const nop = () => {}
